<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ast">
<context>
    <name>FileControl</name>
    <message>
        <location filename="../src/filecontrol.cpp" line="785"/>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="789"/>
        <source>Exit fullscreen</source>
        <translation>Colar de pantalla completa</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="793"/>
        <source>Extract text</source>
        <translation>استخراج النص</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="797"/>
        <source>Slide show</source>
        <translation>Diapositiva</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="801"/>
        <source>Rename</source>
        <translation>Renomar</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="805"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="809"/>
        <source>Delete</source>
        <translation>Desaniciar</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="813"/>
        <source>Rotate clockwise</source>
        <translation>Voltiar a drecha</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="817"/>
        <source>Rotate counterclockwise</source>
        <translation>Voltiar a esquierda</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="821"/>
        <source>Set as wallpaper</source>
        <translation>Afitar como fondu de pantalla</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="825"/>
        <source>Display in file manager</source>
        <translation>Amosar nel xestor de ficheros</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="829"/>
        <source>Image info</source>
        <translation>Información d'imaxe</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="833"/>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="837"/>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="841"/>
        <source>Zoom in</source>
        <translation>تكبير</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="845"/>
        <source>Zoom out</source>
        <translation>تصغير</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="849"/>
        <source>Open</source>
        <translation>فتح</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="853"/>
        <source>Print</source>
        <translation>Imprentar</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="877"/>
        <source>Image Viewing</source>
        <translation>Visión d'imáxenes</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="881"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="885"/>
        <source>Display shortcuts</source>
        <translation>Amosar atayos</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="893"/>
        <source>Settings</source>
        <translation>Axustes</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="901"/>
        <source>Select all</source>
        <translation>اختر الكل</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="909"/>
        <source>Live Text</source>
        <translation>النص الحي</translation>
    </message>
</context>
<context>
    <name>InformationDialog</name>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="74"/>
        <source>Basic info</source>
        <translation>المعلومات الأساسية</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="98"/>
        <source>Size</source>
        <translation>الحجم</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="124"/>
        <source>Date captured</source>
        <translation>تاريخ التقاط الصورة</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="131"/>
        <source>Date modified</source>
        <translation>Data de modificación</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="141"/>
        <source>Details</source>
        <translation>التفاصيل</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="154"/>
        <source>Aperture</source>
        <translation>Apertura</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="162"/>
        <source>Exposure program</source>
        <translation>Programa d'esposición</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="169"/>
        <source>Focal length</source>
        <translation>Llonxitú focal</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="175"/>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="182"/>
        <source>Exposure mode</source>
        <translation>Mou d'esposición</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="188"/>
        <source>Exposure time</source>
        <translation>Tiempu d'esposición</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="194"/>
        <source>Flash</source>
        <translation>Flax</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="201"/>
        <source>Flash compensation</source>
        <translation>Compensación de flax</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="214"/>
        <source>Colorspace</source>
        <translation>Espaciu de colores</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="221"/>
        <source>Metering mode</source>
        <translation>Mou de midición</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="228"/>
        <source>White balance</source>
        <translation>Balance de blancos</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="246"/>
        <source>Lens model</source>
        <translation>Modelu de lente</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="87"/>
        <source>File name</source>
        <translation>اسم الملف</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="105"/>
        <source>Dimensions</source>
        <translation>الأبعاد</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="112"/>
        <source>Type</source>
        <translation>Triba</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="207"/>
        <source>Max aperture</source>
        <translation>Apertura máx.</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="239"/>
        <source>Device model</source>
        <translation>نموذج الجهاز</translation>
    </message>
</context>
<context>
    <name>LiveTextWidget</name>
    <message>
        <location filename="../qml/LiveText/LiveTextWidget.qml" line="155"/>
        <source>Copy (Ctrl+C)</source>
        <translation>نسخ (Ctrl+C)</translation>
    </message>
    <message>
        <location filename="../qml/LiveText/LiveTextWidget.qml" line="172"/>
        <source>Select all (Ctrl+A)</source>
        <translation>اختر الكل (Ctrl+A)</translation>
    </message>
</context>
<context>
    <name>MainStack</name>
    <message>
        <location filename="../qml/MainStack.qml" line="127"/>
        <source>Select pictures</source>
        <translation>اختر الصور</translation>
    </message>
</context>
<context>
    <name>NonexistImageDelegate</name>
    <message>
        <location filename="../qml/ImageDelegate/NonexistImageDelegate.qml" line="43"/>
        <source>Image file not found</source>
        <translation>لم يتم العثور على ملف الصورة</translation>
    </message>
</context>
<context>
    <name>OpenImageWidget</name>
    <message>
        <location filename="../qml/OpenImageWidget.qml" line="35"/>
        <source>Open Image</source>
        <translation>فتح الصورة</translation>
    </message>
</context>
<context>
    <name>PropertyActionItemDelegate</name>
    <message>
        <location filename="../qml/InformationDialog/PropertyActionItemDelegate.qml" line="95"/>
        <source>The file already exists, please use another name</source>
        <translation>الملف موجود بالفعل، الرجاء استخدام اسمًا مختلفًا</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="48"/>
        <source>Image Viewer</source>
        <translation>Visor d'imáxenes</translation>
    </message>
    <message>
        <location filename="../src/unionimage/unionimage_global.h" line="102"/>
        <source>day</source>
        <translation>يوم</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>مُعاينة الصور هي أداة عرض الصور بواجهة أنيقة وعملية سلسة.</translation>
    </message>
</context>
<context>
    <name>ReName</name>
    <message>
        <location filename="../qml/ReName.qml" line="70"/>
        <source>Input a new name</source>
        <translation>أدخل اسمًا جديدًا</translation>
    </message>
    <message>
        <location filename="../qml/ReName.qml" line="85"/>
        <source>The file already exists, please use another name</source>
        <translation>تأكيد</translation>
    </message>
    <message>
        <location filename="../qml/ReName.qml" line="141"/>
        <source>Cancel</source>
        <translation>Encaboxar</translation>
    </message>
    <message>
        <location filename="../qml/ReName.qml" line="123"/>
        <source>Confirm</source>
        <translation>لا يمكن نقل "%1" إلى سلة المهملات. هل ترغب في حذفه بشكل دائم؟</translation>
    </message>
</context>
<context>
    <name>RemoveDialog</name>
    <message>
        <location filename="../qml/Dialog/RemoveDialog.qml" line="71"/>
        <source>Cannot move "%1" to the trash. Do you want to permanently delete it?</source>
        <translation>لا يمكن إلغاء هذه العملية</translation>
    </message>
    <message>
        <location filename="../qml/Dialog/RemoveDialog.qml" line="89"/>
        <source>This action cannot be undone</source>
        <translation>الإيقاف المؤقت</translation>
    </message>
    <message>
        <location filename="../qml/Dialog/RemoveDialog.qml" line="101"/>
        <source>Cancel</source>
        <translation>Encaboxar</translation>
    </message>
    <message>
        <location filename="../qml/Dialog/RemoveDialog.qml" line="111"/>
        <source>Confirm</source>
        <translation>تشغيل</translation>
    </message>
</context>
<context>
    <name>SliderShow</name>
    <message>
        <location filename="../qml/SliderShow.qml" line="155"/>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <location filename="../qml/SliderShow.qml" line="172"/>
        <source>Pause</source>
        <translation>الحجم الأصلي</translation>
    </message>
    <message>
        <location filename="../qml/SliderShow.qml" line="172"/>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <location filename="../qml/SliderShow.qml" line="188"/>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <location filename="../qml/SliderShow.qml" line="203"/>
        <source>Exit</source>
        <translation>Colar</translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="173"/>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="148"/>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="209"/>
        <source>Original size</source>
        <translation>Tamañu original</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="228"/>
        <source>Fit to window</source>
        <translation>Axustar a la ventana</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="246"/>
        <source>Rotate</source>
        <translation>Girar</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="519"/>
        <source>Extract text</source>
        <translation>Extraer texto</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="538"/>
        <source>Delete</source>
        <translation>Desaniciar</translation>
    </message>
</context>
<context>
    <name>ViewRightMenu</name>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="38"/>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="38"/>
        <source>Exit fullscreen</source>
        <translation>Colar de pantalla completa</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="57"/>
        <source>Print</source>
        <translation>Imprentar</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="76"/>
        <source>Extract text</source>
        <translation>Extraer texto</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="96"/>
        <source>Slide show</source>
        <translation>Diapositiva</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="117"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="137"/>
        <source>Rename</source>
        <translation>Renomar</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="156"/>
        <source>Delete</source>
        <translation>Desaniciar</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="183"/>
        <source>Rotate clockwise</source>
        <translation>Voltiar a drecha</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="203"/>
        <source>Rotate counterclockwise</source>
        <translation>Voltiar a esquierda</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="231"/>
        <source>Show navigation window</source>
        <translation>Amosar ventana de navegación</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="231"/>
        <source>Hide navigation window</source>
        <translation>Anubrir ventana de navegación</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="243"/>
        <source>Set as wallpaper</source>
        <translation>Afitar como fondu de pantalla</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="263"/>
        <source>Display in file manager</source>
        <translation>Amosar nel xestor de ficheros</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="280"/>
        <source>Image info</source>
        <translation>Información d'imaxe</translation>
    </message>
</context>
<context>
    <name>ViewTopTitle</name>
    <message>
        <location filename="../qml/ViewTopTitle.qml" line="184"/>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Image Viewer ye un herramienta pa visualizar imáxenes con interfaz moderna y rendimientu suave.</translation>
    </message>
    <message>
        <location filename="../qml/ViewTopTitle.qml" line="186"/>
        <source>Image Viewer</source>
        <translation>Visor d'imáxenes</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versión</translation>
    </message>
    <message>
        <source>%1 is released under %2</source>
        <translation>'%1 foi liberada baixo %2'</translation>
    </message>
    <message>
        <location filename="../qml/ViewTopTitle.qml" line="162"/>
        <source>Open image</source>
        <translation>Abrir imaxe</translation>
    </message>
</context>
</TS>
